Struct darklua_core::generator::DenseLuaGenerator
source · [−]pub struct DenseLuaGenerator { /* private fields */ }Expand description
This implementation of LuaGenerator attempts to produce Lua code as small as possible. It is not meant to be read by humans.
Implementations