pub enum Attribute {
Name(NamedAttribute),
Group(AttributeGroup),
}Expand description
Represents a function attribute.
Attributes can be either:
- Named:
@deprecated - Grouped:
@[attribute1, attribute2(args)]
Variants
Name(NamedAttribute)
A named attribute (e.g., @deprecated)
Group(AttributeGroup)
A group of attributes (e.g., @[attr1, attr2])
Implementations
Sourceimpl Attribute
impl Attribute
Sourcepub fn clear_comments(&mut self)
pub fn clear_comments(&mut self)
Clears all comments from the tokens in this node.
Sourcepub fn clear_whitespaces(&mut self)
pub fn clear_whitespaces(&mut self)
Clears all whitespaces information from the tokens in this node.