pub enum LiteralTableEntry {
Field(Box<LiteralTableFieldEntry>),
Value(Box<LiteralExpression>),
}Expand description
An entry in a literal table.
Variants
Field(Box<LiteralTableFieldEntry>)
A named field entry (e.g., { field = value })
Value(Box<LiteralExpression>)
A value entry for array-like tables (e.g., { value })
Implementations
Sourceimpl LiteralTableEntry
impl LiteralTableEntry
Sourcepub fn from_value(value: impl Into<LiteralExpression>) -> Self
pub fn from_value(value: impl Into<LiteralExpression>) -> Self
Creates a value entry from a literal expression.
Sourcepub fn clear_comments(&mut self)
pub fn clear_comments(&mut self)
Clears all comments from the tokens in this node.
Sourcepub fn clear_whitespaces(&mut self)
pub fn clear_whitespaces(&mut self)
Clears all whitespaces information from the tokens in this node.