NumberExpression

Enum NumberExpression 

pub enum NumberExpression {
    Decimal(DecimalNumber),
    Hex(HexNumber),
    Binary(BinaryNumber),
}
Represents a numeric literal expression.

Variants



Decimal(DecimalNumber)

A decimal number (e.g., 123.45, 1e10)



Hex(HexNumber)

A hexadecimal number (e.g., 0xFF, 0x1p2)



Binary(BinaryNumber)

A binary number (e.g., 0b101, 0B1010)

Implementations

Source

impl NumberExpression

pub fn set_uppercase(&mut self, is_uppercase: bool)

Sets whether the number notation should use uppercase letters.

pub fn compute_value(&self) -> f64

Computes the actual numerical value represented by this number expression.

pub fn with_token(self, token: Token) -> Self

Attaches a token to this number expression.

pub fn set_token(&mut self, token: Token)

Attaches a token to this number expression.

pub fn get_token(&self) -> Option<&Token>

Returns a reference to the token attached to this number expression, if any.

pub fn mutate_token(&mut self) -> Option<&mut Token>

Returns a mutable reference to the token attached to this number expression, if any.

pub fn clear_comments(&mut self)

Clears all comments from the tokens in this node.

pub fn clear_whitespaces(&mut self)

Clears all whitespaces information from the tokens in this node.