AttributeGroupElement

Struct AttributeGroupElement 

pub struct AttributeGroupElement { /* private fields */ }
An element within an attribute group.

Elements can have optional arguments: @[attr, attr_with_args(arg1, arg2)].

Implementations

Source

impl AttributeGroupElement

pub fn new(name: impl Into<Identifier>) -> Self

Creates a new attribute group element with the given name.

pub fn with_arguments(self, arguments: impl Into<AttributeArguments>) -> Self

Attaches arguments to this attribute element.

pub fn name(&self) -> &Identifier

Returns the attribute element’s name.

pub fn mutate_name(&mut self) -> &mut Identifier

Returns a mutable reference to the attribute element’s name.

pub fn get_arguments(&self) -> Option<&AttributeArguments>

Returns the attribute element’s arguments, if any.

pub fn mutate_arguments(&mut self) -> Option<&mut AttributeArguments>

Returns a mutable reference to the attribute element’s arguments, if any.

pub fn set_arguments(&mut self, arguments: impl Into<AttributeArguments>)

Sets the arguments for this attribute element.

pub fn remove_arguments(&mut self)

Removes the arguments from this attribute element.

pub fn clear_comments(&mut self)

Clears all comments from the tokens in this node.

pub fn clear_whitespaces(&mut self)

Clears all whitespaces information from the tokens in this node.