pub struct AttributeGroupTokens {
pub opening_attribute_list: Token,
pub closing_bracket: Token,
pub separators: Vec<Token>,
}Expand description
Tokens for an attribute group.
Fields
opening_attribute_list: TokenToken for the @[ opening.
closing_bracket: TokenToken for the closing bracket ]
separators: Vec<Token>Tokens for the commas between entries.
Implementations
Sourceimpl AttributeGroupTokens
impl AttributeGroupTokens
Sourcepub fn clear_comments(&mut self)
pub fn clear_comments(&mut self)
Clears all comments from the tokens in this node.
Sourcepub fn clear_whitespaces(&mut self)
pub fn clear_whitespaces(&mut self)
Clears all whitespaces information from the tokens in this node.