pub struct AttributeTupleArguments { /* private fields */ }Expand description
Tuple arguments for an attribute element.
Implementations
Sourceimpl AttributeTupleArguments
impl AttributeTupleArguments
pub fn with_value(self, value: impl Into<LiteralExpression>) -> Self
pub fn push(&mut self, argument: impl Into<LiteralExpression>)
Sourcepub fn insert(&mut self, index: usize, argument: impl Into<LiteralExpression>)
pub fn insert(&mut self, index: usize, argument: impl Into<LiteralExpression>)
Inserts an argument at the specified index.
Sourcepub fn iter_values(&self) -> impl Iterator<Item = &LiteralExpression>
pub fn iter_values(&self) -> impl Iterator<Item = &LiteralExpression>
Returns an iterator over the argument values.
Sourcepub fn iter_mut_values(
&mut self,
) -> impl Iterator<Item = &mut LiteralExpression>
pub fn iter_mut_values( &mut self, ) -> impl Iterator<Item = &mut LiteralExpression>
Returns a mutable iterator over the argument values.
Sourcepub fn get_tokens(&self) -> Option<&TupleArgumentsTokens>
pub fn get_tokens(&self) -> Option<&TupleArgumentsTokens>
Returns the tokens for this tuple arguments, if any.
Sourcepub fn set_tokens(&mut self, tokens: TupleArgumentsTokens)
pub fn set_tokens(&mut self, tokens: TupleArgumentsTokens)
Sets the tokens for this tuple arguments.
Sourcepub fn with_tokens(self, tokens: TupleArgumentsTokens) -> Self
pub fn with_tokens(self, tokens: TupleArgumentsTokens) -> Self
Attaches tokens to this tuple arguments.
Sourcepub fn clear_comments(&mut self)
pub fn clear_comments(&mut self)
Clears all comments from the tokens in this node.
Sourcepub fn clear_whitespaces(&mut self)
pub fn clear_whitespaces(&mut self)
Clears all whitespaces information from the tokens in this node.