Attributes

Struct Attributes 

pub struct Attributes { /* private fields */ }
A list of function attributes.

Attributes can be either named (e.g., @deprecated) or grouped (e.g., @[attribute1, attribute2()]).

Implementations

Source

impl Attributes

pub fn new() -> Self

Creates a new empty list of attributes.

pub fn with_attribute(self, attribute: impl Into<Attribute>) -> Self

Adds an attribute to this list of attributes.

pub fn append_attribute(&mut self, attribute: impl Into<Attribute>)

Appends an attribute to this list of attributes.

Empty attribute groups are silently ignored.

pub fn iter_attributes(&self) -> impl Iterator<Item = &Attribute>

Returns an iterator over the attributes in this list.

pub fn iter_mut_attributes(&mut self) -> impl Iterator<Item = &mut Attribute>

Returns a mutable iterator over the attributes in this list.

pub fn clear_attributes(&mut self)

Clears all attributes.

pub fn is_empty(&self) -> bool

Returns whether this list of attributes is empty.

pub fn len(&self) -> usize

Returns the number of attributes in this list.

pub fn has_attribute(&self, name: &str) -> bool

Checks if an attribute with the given name exists in this list.

pub fn filter_attributes<F>(&mut self, predicate: F)
where F: Fn(&Attribute) -> bool,

Filters attributes based on a predicate, keeping only those that return true. The predicate receives an immutable reference to each attribute.

pub fn filter_mut_attributes<F>(&mut self, predicate: F)
where F: FnMut(&mut Attribute) -> bool,

Filters attributes based on a mutable predicate, keeping only those that return true. The predicate receives a mutable reference to each attribute, allowing modifications.

pub fn clear_comments(&mut self)

Clears all comments from the tokens in this node.

pub fn clear_whitespaces(&mut self)

Clears all whitespaces information from the tokens in this node.