FunctionAssignment

Struct FunctionAssignment 

pub struct FunctionAssignment { /* private fields */ }
Represents a local function declaration statement.

Implementations

Source

impl FunctionAssignment

pub fn new( identifier: impl Into<Identifier>, block: Block, parameters: Vec<TypedIdentifier>, is_variadic: bool, ) -> Self

Creates a new local function statement.

pub fn from_name( identifier: impl Into<Identifier>, block: impl Into<Block>, ) -> Self

Creates a new local function statement with a given name and block.

pub fn with_attribute(self, attribute: impl Into<Attribute>) -> Self

Adds an attribute to this function statement. Adds to any existing attributes.

pub fn attributes(&self) -> &Attributes

Returns a reference to the attributes of this function statement.

pub fn with_attributes(self, attributes: Attributes) -> Self

Associates attributes with this local function statement. Replaces any existing attributes.

pub fn mutate_attributes(&mut self) -> &mut Attributes

Returns a mutable reference to the attributes of this function statement.

pub fn with_tokens(self, tokens: FunctionAssignmentTokens) -> Self

Sets the tokens for this local function statement.

pub fn set_tokens(&mut self, tokens: FunctionAssignmentTokens)

Sets the tokens for this local function statement.

pub fn get_tokens(&self) -> Option<&FunctionAssignmentTokens>

Returns the tokens for this local function statement, if any.

pub fn mutate_tokens(&mut self) -> Option<&mut FunctionAssignmentTokens>

Returns a mutable reference to the tokens, if any.

pub fn with_assignment_kind(self, kind: AssignmentKind) -> Self

Sets the assignment kind for this function.

pub fn set_assignment_kind(&mut self, kind: AssignmentKind)

Sets the assignment kind for this function.

pub fn get_assignment_kind(&self) -> AssignmentKind

Returns the assignment kind for this function.

pub fn with_parameter(self, parameter: impl Into<TypedIdentifier>) -> Self

Adds a parameter to this function.

pub fn variadic(self) -> Self

Marks this function as variadic.

pub fn with_variadic_type(self, type: impl Into<FunctionVariadicType>) -> Self

Sets the variadic type for this function.

If the function is not already variadic, this will make it variadic.

pub fn set_variadic_type(&mut self, type: impl Into<FunctionVariadicType>)

Sets the variadic type for this function.

If the function is not already variadic, this will make it variadic.

pub fn get_variadic_type(&self) -> Option<&FunctionVariadicType>

Returns the variadic type, if any.

pub fn has_variadic_type(&self) -> bool

Returns whether this function has a variadic type.

pub fn mutate_variadic_type(&mut self) -> Option<&mut FunctionVariadicType>

Returns a mutable reference to the variadic type, if any.

pub fn with_return_type( self, return_type: impl Into<FunctionReturnType>, ) -> Self

Sets the return type for this function.

pub fn set_return_type(&mut self, return_type: impl Into<FunctionReturnType>)

Sets the return type for this function.

pub fn get_return_type(&self) -> Option<&FunctionReturnType>

Returns the return type, if any.

pub fn has_return_type(&self) -> bool

Returns whether this function has a return type.

pub fn mutate_return_type(&mut self) -> Option<&mut FunctionReturnType>

Returns a mutable reference to the return type, if any.

pub fn with_generic_parameters( self, generic_parameters: GenericParameters, ) -> Self

Sets the generic parameters for this function.

pub fn set_generic_parameters(&mut self, generic_parameters: GenericParameters)

Sets the generic parameters for this function.

pub fn get_generic_parameters(&self) -> Option<&GenericParameters>

Returns the generic parameters, if any.

pub fn mutate_parameters(&mut self) -> &mut Vec<TypedIdentifier>

Returns a mutable reference to the parameters.

pub fn mutate_block(&mut self) -> &mut Block

Returns a mutable reference to the block.

pub fn mutate_identifier(&mut self) -> &mut Identifier

Returns a mutable reference to the identifier.

pub fn get_block(&self) -> &Block

Returns the function’s block.

pub fn get_parameters(&self) -> &Vec<TypedIdentifier>

Returns the function’s parameters.

pub fn iter_parameters(&self) -> impl Iterator<Item = &TypedIdentifier>

Returns an iterator over the parameters.

pub fn iter_mut_parameters( &mut self, ) -> impl Iterator<Item = &mut TypedIdentifier>

Returns a mutable iterator over the parameters.

pub fn get_identifier(&self) -> &Identifier

Returns the function’s identifier.

pub fn get_name(&self) -> &str

Returns the function’s name.

pub fn has_parameter(&self, name: &str) -> bool

Returns whether this function has a parameter with the given name.

pub fn has_parameters(&self) -> bool

Returns whether this function has parameters.

pub fn is_variadic(&self) -> bool

Returns whether this function is variadic.

pub fn parameters_count(&self) -> usize

Returns the number of parameters.

pub fn clear_types(&mut self)

Removes all type annotations from this function.

pub fn mutate_first_token(&mut self) -> &mut Token

Returns a mutable reference to the first token for this statement, creating it if missing.

pub fn mutate_last_token(&mut self) -> &mut Token

Returns a mutable reference to the last token for this statement, creating it if missing.

pub fn clear_comments(&mut self)

Clears all comments from the tokens in this node.

pub fn clear_whitespaces(&mut self)

Clears all whitespaces information from the tokens in this node.