pub struct FunctionAssignmentTokens {
pub keyword: Token,
pub function_body: FunctionBodyTokens,
}Expand description
Tokens associated with a local function statement.
Fields
keyword: Tokenfunction_body: FunctionBodyTokensImplementations
Sourceimpl FunctionAssignmentTokens
impl FunctionAssignmentTokens
Sourcepub fn clear_comments(&mut self)
pub fn clear_comments(&mut self)
Clears all comments from the tokens in this node.
Sourcepub fn clear_whitespaces(&mut self)
pub fn clear_whitespaces(&mut self)
Clears all whitespaces information from the tokens in this node.
Methods from Deref<Target = FunctionBodyTokens>
Sourcepub fn clear_comments(&mut self)
pub fn clear_comments(&mut self)
Clears all comments from the tokens in this node.
Sourcepub fn clear_whitespaces(&mut self)
pub fn clear_whitespaces(&mut self)
Clears all whitespaces information from the tokens in this node.