FunctionExpression

Struct FunctionExpression 

pub struct FunctionExpression { /* private fields */ }
Represents a function expression.

A function expression defines an anonymous function with parameters, a body, and optional features like variadics, return types, and generic parameters.

local add = function(a: number, b: number): number
    return a + b
end

Implementations

Source

impl FunctionExpression

pub fn new( block: Block, parameters: Vec<TypedIdentifier>, is_variadic: bool, ) -> Self

Creates a new function expression with the given block, parameters, and variadic flag.

pub fn from_block<B: Into<Block>>(block: B) -> Self

Creates a new function expression from a block with no parameters.

pub fn attributes(&self) -> &Attributes

Returns a reference to the attributes of this function expression.

pub fn mutate_attributes(&mut self) -> &mut Attributes

Returns a mutable reference to the attributes of this function expression.

pub fn with_attributes(self, attributes: Attributes) -> Self

Associates attributes with this function expression. Replaces any existing attributes.

pub fn with_attribute(self, attribute: impl Into<Attribute>) -> Self

Adds an attribute to this function statement. Adds to any existing attributes.

pub fn with_parameters(self, parameters: Vec<TypedIdentifier>) -> Self

Sets the parameters of this function expression.

pub fn with_parameter(self, parameter: impl Into<TypedIdentifier>) -> Self

Adds a parameter to this function expression.

pub fn with_variadic_type(self, type: impl Into<FunctionVariadicType>) -> Self

Sets the variadic type of this function expression.

This also marks the function as variadic if it is not already.

pub fn with_return_type( self, return_type: impl Into<FunctionReturnType>, ) -> Self

Sets the return type of this function expression.

pub fn set_return_type(&mut self, return_type: impl Into<FunctionReturnType>)

Sets the return type of this function expression.

pub fn get_return_type(&self) -> Option<&FunctionReturnType>

Returns a reference to the return type of this function expression, if any.

pub fn has_return_type(&self) -> bool

Returns whether this function expression has a return type.

pub fn mutate_return_type(&mut self) -> Option<&mut FunctionReturnType>

Returns a mutable reference to the return type of this function expression, if any.

pub fn variadic(self) -> Self

Marks this function expression as variadic and returns the updated expression.

pub fn set_variadic(&mut self, is_variadic: bool)

Sets whether this function expression is variadic.

If set to false, the variadic type is cleared if present.

pub fn set_variadic_type(&mut self, type: impl Into<FunctionVariadicType>)

Sets the variadic type of this function expression.

This also marks the function as variadic if it is not already.

pub fn get_variadic_type(&self) -> Option<&FunctionVariadicType>

Returns a reference to the variadic type of this function expression, if any.

pub fn has_variadic_type(&self) -> bool

Returns whether this function expression has a variadic type.

pub fn mutate_variadic_type(&mut self) -> Option<&mut FunctionVariadicType>

Returns a mutable reference to the variadic type of this function expression, if any.

pub fn with_generic_parameters( self, generic_parameters: GenericParameters, ) -> Self

Sets the generic parameters of this function expression and returns the updated expression.

pub fn set_generic_parameters(&mut self, generic_parameters: GenericParameters)

Sets the generic parameters of this function expression.

pub fn get_generic_parameters(&self) -> Option<&GenericParameters>

Returns a reference to the generic parameters of this function expression, if any.

pub fn is_generic(&self) -> bool

Returns whether this function expression has generic parameters.

pub fn with_tokens(self, tokens: FunctionBodyTokens) -> Self

Associates a token with this function expression.

pub fn set_tokens(&mut self, tokens: FunctionBodyTokens)

Associates a token with this function expression.

pub fn get_tokens(&self) -> Option<&FunctionBodyTokens>

Returns a reference to the token attached to this function expression, if any.

pub fn get_block(&self) -> &Block

Returns a reference to the block of this function expression.

pub fn get_parameters(&self) -> &Vec<TypedIdentifier>

Returns a reference to the parameters of this function expression.

pub fn iter_parameters(&self) -> impl Iterator<Item = &TypedIdentifier>

Returns an iterator over the parameters of this function expression.

pub fn iter_mut_parameters( &mut self, ) -> impl Iterator<Item = &mut TypedIdentifier>

Returns a mutable iterator over the parameters of this function expression.

pub fn is_variadic(&self) -> bool

Returns whether this function expression is variadic.

pub fn mutate_block(&mut self) -> &mut Block

Returns a mutable reference to the block of this function expression.

pub fn mutate_parameters(&mut self) -> &mut Vec<TypedIdentifier>

Returns a mutable reference to the parameters of this function expression.

pub fn parameters_count(&self) -> usize

Returns the number of parameters of this function expression.

pub fn has_parameters(&self) -> bool

Returns whether this function expression has parameters.

pub fn clear_types(&mut self)

Removes all type information from this function expression.

This includes return type, variadic type, generic parameters, and parameter types.

pub fn mutate_first_token(&mut self) -> &mut Token

Returns a mutable reference to the first token for this function expression, creating it if missing.

pub fn mutate_last_token(&mut self) -> &mut Token

Returns a mutable reference to the last token for this function expression, creating it if missing.

pub fn clear_comments(&mut self)

Clears all comments from the tokens in this node.

pub fn clear_whitespaces(&mut self)

Clears all whitespaces information from the tokens in this node.