FunctionName

Struct FunctionName 

pub struct FunctionName { /* private fields */ }
Represents the name portion of a function statement.

Function names can include table fields and methods ([e.g., module.table:method]).

Implementations

Source

impl FunctionName

pub fn new( name: Identifier, field_names: Vec<Identifier>, method: Option<Identifier>, ) -> Self

Creates a new function name with fields and an optional method.

pub fn from_name<S: Into<Identifier>>(name: S) -> Self

Creates a new function name from a single identifier.

pub fn with_tokens(self, tokens: FunctionNameTokens) -> Self

Sets the tokens for this function name.

pub fn set_tokens(&mut self, tokens: FunctionNameTokens)

Sets the tokens for this function name.

pub fn get_tokens(&self) -> Option<&FunctionNameTokens>

Returns the tokens for this function name, if any.

pub fn with_field<S: Into<Identifier>>(self, field: S) -> Self

Adds a field to this function name.

pub fn with_fields(self, field_names: Vec<Identifier>) -> Self

Sets the field names for this function name.

pub fn with_method<S: Into<Identifier>>(self, method: S) -> Self

Sets a method for this function name.

pub fn push_field<S: Into<Identifier>>(&mut self, field: S)

Adds a field to this function name.

pub fn remove_method(&mut self) -> Option<Identifier>

Removes and returns the method, if any.

pub fn get_method(&self) -> Option<&Identifier>

Returns the method, if any.

pub fn has_method(&self) -> bool

Returns whether this function name has a method component.

pub fn get_name(&self) -> &Identifier

Returns the base name.

pub fn set_name(&mut self, name: Identifier)

Sets the base name.

pub fn get_field_names(&self) -> &Vec<Identifier>

Returns the field names.

pub fn mutate_identifier(&mut self) -> &mut Identifier

Returns a mutable reference to the base identifier.

pub fn clear_comments(&mut self)

Clears all comments from the tokens in this node.

pub fn clear_whitespaces(&mut self)

Clears all whitespaces information from the tokens in this node.