GenericParametersWithDefaults

Struct GenericParametersWithDefaults 

pub struct GenericParametersWithDefaults { /* private fields */ }
Represents a collection of generic parameters that may include default values.

Implementations

Source

impl GenericParametersWithDefaults

pub fn from_type_variable(identifier: impl Into<Identifier>) -> Self

Creates new generic parameters with a single type variable.

pub fn from_type_variable_with_default( type_variable_with_default: TypeVariableWithDefault, ) -> Self

Creates new generic parameters with a single type variable that has a default value.

pub fn from_generic_type_pack(generic_type_pack: GenericTypePack) -> Self

Creates new generic parameters with a single generic type pack.

pub fn from_generic_type_pack_with_default( generic_type_pack_with_default: GenericTypePackWithDefault, ) -> Self

Creates new generic parameters with a single generic type pack that has a default value.

pub fn with_type_variable(self, identifier: impl Into<Identifier>) -> Self

Adds a type variable to these generic parameters.

pub fn push_type_variable(&mut self, type_variable: impl Into<Identifier>)

Adds a type variable to these generic parameters.

pub fn with_type_variable_with_default( self, type_variable_with_default: TypeVariableWithDefault, ) -> Option<Self>

Adds a type variable with a default value to these generic parameters.

Returns None if the operation would mix type variables with default values and generic type packs.

pub fn push_type_variable_with_default( &mut self, type_variable_with_default: TypeVariableWithDefault, ) -> bool

Adds a type variable with a default value to these generic parameters.

Returns false if the operation would mix type variables with default values and generic type packs.

pub fn with_generic_type_pack( self, generic_type_pack: GenericTypePack, ) -> Option<Self>

Adds a generic type pack to these generic parameters.

Returns None if the operation would mix generic type packs and type variables with default values.

pub fn push_generic_type_pack( &mut self, generic_type_pack: GenericTypePack, ) -> bool

Adds a generic type pack to these generic parameters.

Returns false if the operation would mix generic type packs and type variables with default values.

pub fn with_generic_type_pack_with_default( self, generic_type_pack_with_default: GenericTypePackWithDefault, ) -> Self

Adds a generic type pack with a default value to these generic parameters.

pub fn push_generic_type_pack_with_default( &mut self, generic_type_pack_with_default: GenericTypePackWithDefault, )

Adds a generic type pack with a default value to these generic parameters.

pub fn with_tokens(self, tokens: GenericParametersTokens) -> Self

Associates tokens with these generic parameters.

pub fn set_tokens(&mut self, tokens: GenericParametersTokens)

Sets the tokens associated with these generic parameters.

pub fn get_tokens(&self) -> Option<&GenericParametersTokens>

Returns the tokens associated with these generic parameters, if any.

pub fn iter(&self) -> impl Iterator<Item = GenericParameterRef<'_>>

Returns an iterator over references to the generic parameters.

pub fn iter_mut(&mut self) -> impl Iterator<Item = GenericParameterMutRef<'_>>

Returns a mutable iterator over references to the generic parameters.

pub fn len(&self) -> usize

Returns the total number of generic parameters.

pub fn is_empty(&self) -> bool

Returns whether there are no generic parameters.

pub fn clear_comments(&mut self)

Clears all comments from the tokens in this node.

pub fn clear_whitespaces(&mut self)

Clears all whitespaces information from the tokens in this node.