IfStatement

Struct IfStatement 

pub struct IfStatement { /* private fields */ }
Represents an if statement.

Implementations

Source

impl IfStatement

pub fn new(branches: Vec<IfBranch>, else_block: Option<Block>) -> Self

Creates a new if statement with the given branches and optional else block.

pub fn create(condition: impl Into<Expression>, block: impl Into<Block>) -> Self

Creates a new if statement with a single condition and block.

pub fn with_tokens(self, tokens: IfStatementTokens) -> Self

Sets the tokens for this if statement.

pub fn set_tokens(&mut self, tokens: IfStatementTokens)

Sets the tokens for this if statement.

pub fn get_tokens(&self) -> Option<&IfStatementTokens>

Returns the tokens for this if statement, if any.

pub fn mutate_tokens(&mut self) -> Option<&mut IfStatementTokens>

Returns a mutable reference to the tokens, if any.

pub fn with_branch(self, branch: IfBranch) -> Self

Adds a branch to this if statement.

pub fn with_new_branch( self, condition: impl Into<Expression>, block: impl Into<Block>, ) -> Self

Adds a new branch with the given condition and block.

pub fn with_else_block<B: Into<Block>>(self, block: B) -> Self

Adds an else block to this if statement.

pub fn mutate_all_blocks(&mut self) -> Vec<&mut Block>

Returns mutable references to all blocks in this if statement.

pub fn get_branches(&self) -> &Vec<IfBranch>

Returns the branches of this if statement.

pub fn iter_branches(&self) -> impl Iterator<Item = &IfBranch>

Returns an iterator over the branches.

pub fn branch_count(&self) -> usize

Returns the number of branches.

pub fn mutate_branches(&mut self) -> &mut Vec<IfBranch>

Returns a mutable reference to the branches.

pub fn push_new_branch( &mut self, condition: impl Into<Expression>, block: impl Into<Block>, )

Adds a new branch with the given condition and block.

pub fn push_branch(&mut self, branch: IfBranch)

Adds a branch to this if statement.

pub fn get_else_block(&self) -> Option<&Block>

Returns the else block, if any.

pub fn mutate_else_block(&mut self) -> &mut Option<Block>

Returns a mutable reference to the else block option.

pub fn set_else_block(&mut self, block: impl Into<Block>)

Sets the else block.

pub fn take_else_block(&mut self) -> Option<Block>

Removes the else block, if any.

pub fn retain_branches_mut( &mut self, filter: impl FnMut(&mut IfBranch) -> bool, ) -> bool

Filters branches in-place, ensuring at least one branch remains.

pub fn mutate_first_token(&mut self) -> &mut Token

Returns a mutable reference to the first token for this statement, creating it if missing.

pub fn mutate_last_token(&mut self) -> &mut Token

Returns a mutable reference to the last token for this statement, creating it if missing.

pub fn clear_comments(&mut self)

Clears all comments from the tokens in this node.

pub fn clear_whitespaces(&mut self)

Clears all whitespaces information from the tokens in this node.