pub struct LiteralTable { /* private fields */ }Expand description
A literal table in Luau.
Table literals follow the syntax { entry1, entry2, key = value }.
Implementations
Sourceimpl LiteralTable
impl LiteralTable
Sourcepub fn from_entries(entries: Vec<LiteralTableEntry>) -> Self
pub fn from_entries(entries: Vec<LiteralTableEntry>) -> Self
Creates a new literal table from a vector of entries.
Sourcepub fn with_entry(self, entry: impl Into<LiteralTableEntry>) -> Self
pub fn with_entry(self, entry: impl Into<LiteralTableEntry>) -> Self
Adds an entry to this table.
Sourcepub fn append_entry(&mut self, entry: impl Into<LiteralTableEntry>)
pub fn append_entry(&mut self, entry: impl Into<LiteralTableEntry>)
Appends an entry to this table.
Sourcepub fn append_field(
&mut self,
field: Identifier,
value: impl Into<LiteralExpression>,
)
pub fn append_field( &mut self, field: Identifier, value: impl Into<LiteralExpression>, )
Appends a field entry to this table.
Sourcepub fn append_array_value(&mut self, value: impl Into<LiteralExpression>)
pub fn append_array_value(&mut self, value: impl Into<LiteralExpression>)
Appends an array value entry to this table.
Sourcepub fn iter_entries(&self) -> impl Iterator<Item = &LiteralTableEntry>
pub fn iter_entries(&self) -> impl Iterator<Item = &LiteralTableEntry>
Returns an iterator over the table entries.
Sourcepub fn iter_mut_entries(
&mut self,
) -> impl Iterator<Item = &mut LiteralTableEntry>
pub fn iter_mut_entries( &mut self, ) -> impl Iterator<Item = &mut LiteralTableEntry>
Returns a mutable iterator over the table entries.
Sourcepub fn with_tokens(self, tokens: TableTokens) -> Self
pub fn with_tokens(self, tokens: TableTokens) -> Self
Attaches tokens to this table.
Sourcepub fn set_tokens(&mut self, tokens: TableTokens)
pub fn set_tokens(&mut self, tokens: TableTokens)
Sets the tokens for this table.
Sourcepub fn get_tokens(&self) -> Option<&TableTokens>
pub fn get_tokens(&self) -> Option<&TableTokens>
Returns the tokens for this table, if any.
Sourcepub fn clear_comments(&mut self)
pub fn clear_comments(&mut self)
Clears all comments from the tokens in this node.
Sourcepub fn clear_whitespaces(&mut self)
pub fn clear_whitespaces(&mut self)
Clears all whitespaces information from the tokens in this node.