LiteralTableFieldEntry

Struct LiteralTableFieldEntry 

pub struct LiteralTableFieldEntry { /* private fields */ }
A field entry in a literal table.

Represents a named field assignment: { field = value }.

Implementations

Source

impl LiteralTableFieldEntry

pub fn with_token(self, token: Token) -> Self

Attaches a token to this field entry for the = symbol.

pub fn set_token(&mut self, token: Token)

Sets the token for this field entry’s = symbol.

pub fn get_token(&self) -> Option<&Token>

Returns the token for this field entry’s = symbol, if any.

pub fn get_field(&self) -> &Identifier

Returns the field name.

pub fn mutate_field(&mut self) -> &mut Identifier

Returns a mutable reference to the field name.

pub fn get_value(&self) -> &LiteralExpression

Returns the field value.

pub fn mutate_value(&mut self) -> &mut LiteralExpression

Returns a mutable reference to the field value.

pub fn mutate_token(&mut self) -> Option<&mut Token>

Returns a mutable reference to the token for this field entry’s = symbol, if any.

pub fn clear_comments(&mut self)

Clears all comments from the tokens in this node.

pub fn clear_whitespaces(&mut self)

Clears all whitespaces information from the tokens in this node.