NamedAttribute

Struct NamedAttribute 

pub struct NamedAttribute { /* private fields */ }
A named function attribute.

Named attributes follow the syntax @name, such as @deprecated.

Implementations

Source

impl NamedAttribute

pub fn new(name: impl Into<Identifier>) -> Self

Creates a new named attribute with the given name.

pub fn with_token(self, token: Token) -> Self

Attaches a token to this named attribute for the @ symbol.

pub fn set_token(&mut self, token: Token)

Sets the token for this named attribute’s @ symbol.

pub fn get_token(&self) -> Option<&Token>

Returns the token for this named attribute’s @ symbol, if any.

pub fn get_identifier(&self) -> &Identifier

Returns the attribute’s name.

pub fn mutate_identifier(&mut self) -> &mut Identifier

Returns a mutable reference to the attribute’s name.

pub fn clear_comments(&mut self)

Clears all comments from the tokens in this node.

pub fn clear_whitespaces(&mut self)

Clears all whitespaces information from the tokens in this node.