Trivia

Struct Trivia 

pub struct Trivia { /* private fields */ }
Represents a piece of trivia (whitespace or comments) in the source code.

Implementations

Source

impl Trivia

pub fn read<'a: 'b, 'b>(&'a self, code: &'b str) -> &'b str

Reads the content of the trivia from the source code.

Panics

Panics if the position is a line number reference and the range is invalid.

pub fn try_read(&self) -> Option<&str>

Attempts to read the content of the trivia without requiring source code.

Returns None if the position is a line number reference, as it requires source code to read.

pub fn kind(&self) -> TriviaKind

Returns the kind of trivia.

pub fn get_line_number(&self) -> Option<usize>

Returns the line number of the trivia, if available.