pub struct TypePackTokens {
pub left_parenthese: Token,
pub right_parenthese: Token,
pub commas: Vec<Token>,
}Expand description
Contains the tokens that define the type pack syntax.
These tokens represent the parentheses and commas in a type pack.
Fields
left_parenthese: TokenThe left parenthesis token.
right_parenthese: TokenThe right parenthesis token.
commas: Vec<Token>The comma tokens separating the types.
Implementations
Sourceimpl TypePackTokens
impl TypePackTokens
Sourcepub fn clear_comments(&mut self)
pub fn clear_comments(&mut self)
Clears all comments from the tokens in this node.
Sourcepub fn clear_whitespaces(&mut self)
pub fn clear_whitespaces(&mut self)
Clears all whitespaces information from the tokens in this node.