pub struct VariableAssignmentTokens {
pub keyword: Token,
pub equal: Option<Token>,
pub variable_commas: Vec<Token>,
pub value_commas: Vec<Token>,
}Expand description
Tokens associated with a local variable assignment statement.
Fields
keyword: Tokenequal: Option<Token>The token for the equal sign, if any.
variable_commas: Vec<Token>The tokens for the commas between variables.
value_commas: Vec<Token>The tokens for the commas between values.
Implementations
Sourceimpl VariableAssignmentTokens
impl VariableAssignmentTokens
Sourcepub fn clear_comments(&mut self)
pub fn clear_comments(&mut self)
Clears all comments from the tokens in this node.
Sourcepub fn clear_whitespaces(&mut self)
pub fn clear_whitespaces(&mut self)
Clears all whitespaces information from the tokens in this node.