A collection of utility processors that can be used when creating rules.
Structs
- Collect
Globals Processor - Find
Variables - A processor to find usage of a given set of identifiers.
A collection of utility processors that can be used when creating rules.