Enum darklua_core::rules::RulePropertyValue
source · [−]pub enum RulePropertyValue {
Boolean(bool),
String(String),
Usize(usize),
Float(f64),
StringList(Vec<String>),
None,
}Expand description
In order to be able to weakly-type the properties of any rule, this enum makes it possible to easily use serde to gather the value associated with a property.
Variants
Boolean(bool)
String(String)
Usize(usize)
Float(f64)
StringList(Vec<String>)
None