pub struct RuleMetadata { /* private fields */ }Expand description
Metadata for a rule.
This struct contains information about the rule that is used to filter out rules that are not applicable to the current context.
Implementations
Sourceimpl RuleMetadata
impl RuleMetadata
pub fn with_apply_to_filter(self, filter: String) -> Result<Self, DarkluaError>
pub fn push_apply_to_filter( &mut self, filter: String, ) -> Result<(), DarkluaError>
pub fn with_skip_filter(self, filter: String) -> Result<Self, DarkluaError>
pub fn push_skip_filter(&mut self, filter: String) -> Result<(), DarkluaError>