pub trait Rule: RuleConfiguration {
    fn process(
        &self,
        block: &mut Block,
        context: &mut Context
    ) -> RuleProcessResult; }
Defines an interface that will be used to mutate blocks and how to serialize and deserialize the rule configuration.

Required Methods

This method should mutate the given block to apply the rule.