pub struct Configuration { /* private fields */ }Expand description
Configuration for processing files (rules, generator, bundling).
Implementations
Sourceimpl Configuration
impl Configuration
Sourcepub fn empty() -> Self
pub fn empty() -> Self
Creates a configuration object without any rules and with the default generator.
Sourcepub fn with_generator(self, generator: GeneratorParameters) -> Self
pub fn with_generator(self, generator: GeneratorParameters) -> Self
Sets the generator parameters for this configuration.
Sourcepub fn set_generator(&mut self, generator: GeneratorParameters)
pub fn set_generator(&mut self, generator: GeneratorParameters)
Sets the generator parameters for this configuration.
Sourcepub fn with_rule(self, rule: impl Into<Box<dyn Rule>>) -> Self
pub fn with_rule(self, rule: impl Into<Box<dyn Rule>>) -> Self
Adds a rule to this configuration.
Sourcepub fn with_bundle_configuration(
self,
configuration: BundleConfiguration,
) -> Self
pub fn with_bundle_configuration( self, configuration: BundleConfiguration, ) -> Self
Sets the bundle configuration for this configuration.
Sourcepub fn with_location(self, location: impl Into<PathBuf>) -> Self
pub fn with_location(self, location: impl Into<PathBuf>) -> Self
Sets the location of this configuration.
Sourcepub fn with_apply_to_filter(
self,
apply_to_files: &str,
) -> Result<Self, DarkluaError>
pub fn with_apply_to_filter( self, apply_to_files: &str, ) -> Result<Self, DarkluaError>
Adds a glob pattern so that rules will be only applied to files matching it. Returns an error if the pattern is invalid.
Sourcepub fn push_apply_to_filter(
&mut self,
apply_to_files: &str,
) -> Result<(), DarkluaError>
pub fn push_apply_to_filter( &mut self, apply_to_files: &str, ) -> Result<(), DarkluaError>
Adds a glob pattern so that rules will be only applied to files matching it. Returns an error if the pattern is invalid.
Sourcepub fn with_skip_filter(self, skip_files: &str) -> Result<Self, DarkluaError>
pub fn with_skip_filter(self, skip_files: &str) -> Result<Self, DarkluaError>
Adds a glob pattern so that rules will be skipped for files matching it. Returns an error if the pattern is invalid.
Sourcepub fn push_skip_filter(&mut self, skip_files: &str) -> Result<(), DarkluaError>
pub fn push_skip_filter(&mut self, skip_files: &str) -> Result<(), DarkluaError>
Adds a glob pattern so that rules will be skipped for files matching it. Returns an error if the pattern is invalid.