AttributeArguments

Enum AttributeArguments 

pub enum AttributeArguments {
    Tuple(AttributeTupleArguments),
    String(StringExpression),
    Table(LiteralTable),
}
Arguments for an attribute element.

Attributes can accept tuple arguments, string literals, or table literals:

  • Tuple: @[attr(true, 0)]
  • String: @[attr "text"]
  • Table: @[attr { key = value }]

Variants



Tuple(AttributeTupleArguments)

Tuple arguments: attr("hello", 0)



String(StringExpression)

String argument: attr "text"



Table(LiteralTable)

Table argument: attr { key = value }

Implementations

Source

impl AttributeArguments

pub fn clear_comments(&mut self)

Clears all comments from the tokens in this node.

pub fn clear_whitespaces(&mut self)

Clears all whitespaces information from the tokens in this node.