pub struct AttributeGroupElement { /* private fields */ }Expand description
An element within an attribute group.
Elements can have optional arguments: @[attr, attr_with_args(arg1, arg2)].
Implementations
Sourceimpl AttributeGroupElement
impl AttributeGroupElement
Sourcepub fn new(name: impl Into<Identifier>) -> Self
pub fn new(name: impl Into<Identifier>) -> Self
Creates a new attribute group element with the given name.
Sourcepub fn with_arguments(self, arguments: impl Into<AttributeArguments>) -> Self
pub fn with_arguments(self, arguments: impl Into<AttributeArguments>) -> Self
Attaches arguments to this attribute element.
Sourcepub fn name(&self) -> &Identifier
pub fn name(&self) -> &Identifier
Returns the attribute element’s name.
Sourcepub fn mutate_name(&mut self) -> &mut Identifier
pub fn mutate_name(&mut self) -> &mut Identifier
Returns a mutable reference to the attribute element’s name.
Sourcepub fn get_arguments(&self) -> Option<&AttributeArguments>
pub fn get_arguments(&self) -> Option<&AttributeArguments>
Returns the attribute element’s arguments, if any.
Sourcepub fn mutate_arguments(&mut self) -> Option<&mut AttributeArguments>
pub fn mutate_arguments(&mut self) -> Option<&mut AttributeArguments>
Returns a mutable reference to the attribute element’s arguments, if any.
Sourcepub fn set_arguments(&mut self, arguments: impl Into<AttributeArguments>)
pub fn set_arguments(&mut self, arguments: impl Into<AttributeArguments>)
Sets the arguments for this attribute element.
Sourcepub fn remove_arguments(&mut self)
pub fn remove_arguments(&mut self)
Removes the arguments from this attribute element.
Sourcepub fn clear_comments(&mut self)
pub fn clear_comments(&mut self)
Clears all comments from the tokens in this node.
Sourcepub fn clear_whitespaces(&mut self)
pub fn clear_whitespaces(&mut self)
Clears all whitespaces information from the tokens in this node.