pub struct Attributes { /* private fields */ }Expand description
A list of function attributes.
Attributes can be either named (e.g., @deprecated) or grouped
(e.g., @[attribute1, attribute2()]).
Implementations
Sourceimpl Attributes
impl Attributes
Sourcepub fn with_attribute(self, attribute: impl Into<Attribute>) -> Self
pub fn with_attribute(self, attribute: impl Into<Attribute>) -> Self
Adds an attribute to this list of attributes.
Sourcepub fn append_attribute(&mut self, attribute: impl Into<Attribute>)
pub fn append_attribute(&mut self, attribute: impl Into<Attribute>)
Appends an attribute to this list of attributes.
Empty attribute groups are silently ignored.
Sourcepub fn iter_attributes(&self) -> impl Iterator<Item = &Attribute>
pub fn iter_attributes(&self) -> impl Iterator<Item = &Attribute>
Returns an iterator over the attributes in this list.
Sourcepub fn iter_mut_attributes(&mut self) -> impl Iterator<Item = &mut Attribute>
pub fn iter_mut_attributes(&mut self) -> impl Iterator<Item = &mut Attribute>
Returns a mutable iterator over the attributes in this list.
Sourcepub fn clear_attributes(&mut self)
pub fn clear_attributes(&mut self)
Clears all attributes.
Sourcepub fn has_attribute(&self, name: &str) -> bool
pub fn has_attribute(&self, name: &str) -> bool
Checks if an attribute with the given name exists in this list.
Sourcepub fn filter_attributes<F>(&mut self, predicate: F)
pub fn filter_attributes<F>(&mut self, predicate: F)
Filters attributes based on a predicate, keeping only those that return true. The predicate receives an immutable reference to each attribute.
Sourcepub fn filter_mut_attributes<F>(&mut self, predicate: F)
pub fn filter_mut_attributes<F>(&mut self, predicate: F)
Filters attributes based on a mutable predicate, keeping only those that return true. The predicate receives a mutable reference to each attribute, allowing modifications.
Sourcepub fn clear_comments(&mut self)
pub fn clear_comments(&mut self)
Clears all comments from the tokens in this node.
Sourcepub fn clear_whitespaces(&mut self)
pub fn clear_whitespaces(&mut self)
Clears all whitespaces information from the tokens in this node.