pub struct LiteralTableFieldEntry { /* private fields */ }Expand description
A field entry in a literal table.
Represents a named field assignment: { field = value }.
Implementations
Sourceimpl LiteralTableFieldEntry
impl LiteralTableFieldEntry
Sourcepub fn with_token(self, token: Token) -> Self
pub fn with_token(self, token: Token) -> Self
Attaches a token to this field entry for the = symbol.
Sourcepub fn get_token(&self) -> Option<&Token>
pub fn get_token(&self) -> Option<&Token>
Returns the token for this field entry’s = symbol, if any.
Sourcepub fn get_field(&self) -> &Identifier
pub fn get_field(&self) -> &Identifier
Returns the field name.
Sourcepub fn mutate_field(&mut self) -> &mut Identifier
pub fn mutate_field(&mut self) -> &mut Identifier
Returns a mutable reference to the field name.
Sourcepub fn get_value(&self) -> &LiteralExpression
pub fn get_value(&self) -> &LiteralExpression
Returns the field value.
Sourcepub fn mutate_value(&mut self) -> &mut LiteralExpression
pub fn mutate_value(&mut self) -> &mut LiteralExpression
Returns a mutable reference to the field value.
Sourcepub fn mutate_token(&mut self) -> Option<&mut Token>
pub fn mutate_token(&mut self) -> Option<&mut Token>
Returns a mutable reference to the token for this field entry’s = symbol, if any.
Sourcepub fn clear_comments(&mut self)
pub fn clear_comments(&mut self)
Clears all comments from the tokens in this node.
Sourcepub fn clear_whitespaces(&mut self)
pub fn clear_whitespaces(&mut self)
Clears all whitespaces information from the tokens in this node.