pub struct NamedAttribute { /* private fields */ }Expand description
A named function attribute.
Named attributes follow the syntax @name, such as @deprecated.
Implementations
Sourceimpl NamedAttribute
impl NamedAttribute
Sourcepub fn new(name: impl Into<Identifier>) -> Self
pub fn new(name: impl Into<Identifier>) -> Self
Creates a new named attribute with the given name.
Sourcepub fn with_token(self, token: Token) -> Self
pub fn with_token(self, token: Token) -> Self
Attaches a token to this named attribute for the @ symbol.
Sourcepub fn get_token(&self) -> Option<&Token>
pub fn get_token(&self) -> Option<&Token>
Returns the token for this named attribute’s @ symbol, if any.
Sourcepub fn get_identifier(&self) -> &Identifier
pub fn get_identifier(&self) -> &Identifier
Returns the attribute’s name.
Sourcepub fn mutate_identifier(&mut self) -> &mut Identifier
pub fn mutate_identifier(&mut self) -> &mut Identifier
Returns a mutable reference to the attribute’s name.
Sourcepub fn clear_comments(&mut self)
pub fn clear_comments(&mut self)
Clears all comments from the tokens in this node.
Sourcepub fn clear_whitespaces(&mut self)
pub fn clear_whitespaces(&mut self)
Clears all whitespaces information from the tokens in this node.