pub struct RemoveAttribute { /* private fields */ }Expand description
A rule that removes function attributes.
When configured with a match parameter containing regex patterns,
only attributes whose names match the patterns are removed.
When match is empty (default), all attributes are removed.
Implementations
Sourceimpl RemoveAttribute
impl RemoveAttribute
Sourcepub fn with_match(self, match_pattern: &str) -> Self
pub fn with_match(self, match_pattern: &str) -> Self
Adds a regex pattern to match against attribute names.